@@ -5,7 +5,7 @@ pub trait RespExtra: Sized {
 
     #[cfg(all(feature = "for-axum", not(feature = "for-actix")))]
     /// axum 框架响应的附加消息添加
-    fn axum_extra(&self, resp: http::response::Builder) -> http::response::Builder {
+    fn axum_extra(self, resp: http::response::Builder) -> http::response::Builder {
         resp
     }
 }
